#include "HapticObserver.h"

#include <Core/observers/checks/ConditionCheckUpdated.h>
#include <Core/observers/checks/ConditionCheckEquals.h>
#include <Core/observers/checks/ConditionCheckInRange.h>
#include <Core/observers/checks/ConditionCheckLarger.h>
#include <Core/observers/checks/ConditionCheckSmaller.h>
#include <Core/robotstate/remote/checks/ConditionCheckMagnitudeChecks.h>

#include <Core/robotstate/remote/RobotStateObjectFactories.h>

using namespace armarx;

HapticObserver::HapticObserver()
{
}

void HapticObserver::setTopicName(std::string topicName)
{
    this->topicName = topicName;
}

void HapticObserver::onInitObserver()
{
    if(topicName.empty())
        usingTopic(getProperty<std::string>("HapticTopicName").getValue());
    else
        usingTopic(topicName);

    // register all checks
    offerConditionCheck("updated", new ConditionCheckUpdated());
    offerConditionCheck("larger", new ConditionCheckLarger());
    offerConditionCheck("equals", new ConditionCheckEquals());
    offerConditionCheck("smaller", new ConditionCheckSmaller());
//    offerConditionCheck("magnitudeinrange", new ConditionCheckInRange());
    offerConditionCheck("magnitudelarger", new ConditionCheckMagnitudeLarger());
//    offerConditionCheck("magnitudesmaller", new ConditionCheckSmaller());

    // register all channels
//    offerChannel(FORCETORQUEVECTORS,"Force and Torque vectors on specific parts of the robot.");

//    offerChannel(RAWFORCE,"Forces on specific parts of the robot.");
//    offerChannel(OFFSETFORCE,"Force Torques of specific parts of the robot with an offset.");
//    offerChannel(FILTEREDFORCE,"Gaussian filtered force torques of specific parts of the robot.");

//    offerChannel(RAWTORQUE,"Torques on specific parts of the robot.");

}

void HapticObserver::onConnectObserver()
{
}

void HapticObserver::reportSensorValues(const std::string &type, const MatrixFloat &values, const Ice::Current &)
{
    // TODO
}

PropertyDefinitionsPtr HapticObserver::createPropertyDefinitions()
{
    return PropertyDefinitionsPtr(new HapticObserverPropertyDefinitions(
                                           getConfigIdentifier()));
}
