/**
 * This file is part of ArmarX.
 *
 * ArmarX is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * ArmarX is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    ArmarXCore::units
 * @author     Peter Kaiser <peter dot kaiser at kit dot edu>
 * @date       2014
 * @copyright  http://www.gnu.org/licenses/gpl.txt
 *             GNU General Public License
 */

#ifndef _ARMARX_COMPONENT_HAPTIC_UNIT_H
#define _ARMARX_COMPONENT_HAPTIC_UNIT_H

#include <Core/core/Component.h>
#include <Core/core/application/properties/Properties.h>
#include <Core/core/system/ImportExportComponent.h>
#include "Core/units/SensorActorUnit.h"

#include <RobotAPI/interface/units/HapticUnit.h>

#include <string>

namespace armarx
{
    class HapticUnitPropertyDefinitions : public ComponentPropertyDefinitions
    {
        public:
            HapticUnitPropertyDefinitions(std::string prefix) :
                ComponentPropertyDefinitions(prefix)
            {
                // No required properties
            }
    };
    
    class HapticUnit :
        virtual public HapticUnitInterface,
        virtual public SensorActorUnit
    {
        public:
            virtual std::string getDefaultName() const { return "HapticUnit"; }
            
            virtual void onInitComponent();
            virtual void onConnectComponent();
            virtual void onExitComponent();
            
            virtual void onInitHapticUnit() = 0;
            virtual void onStartHapticUnit() = 0;
            virtual void onExitHapticUnit() = 0;
            
            virtual PropertyDefinitionsPtr createPropertyDefinitions();
            
        protected:
            HapticUnitListenerPrx listenerPrx;
            std::string listenerName;
    };
}

#endif
